require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscheduledtask',
  dscmeta_resource_friendly_name: 'xScheduledTask',
  dscmeta_resource_name: 'xScheduledTask',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xScheduledTask',
  dscmeta_module_version: '1.0.0.6',
  docs: 'The DSC xScheduledTask resource type.
         Automatically generated from version 1.0.0.6',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_tasktriggers: {
      type: "Optional[Array[Struct[{
              id => Optional[String],
              endboundary => Optional[String],
              daysofweek => Optional[Integer[0, 65535]],
              randomdelay => Optional[String],
              taskrepetition => Struct[{
                duration => Optional[String],
                interval => Optional[String],
                cim_instance_type => Enum['TaskRepetition'],
                stopatdurationend => Optional[Boolean]
              }],
              statechange => Optional[Integer[0, 4294967295]],
              executiontimelimit => Optional[String],
              weeksinterval => Optional[Integer[0, 65535]],
              startboundary => Optional[String],
              userid => Optional[String],
              daysinterval => Optional[Integer[0, 65535]],
              enabled => Optional[Boolean],
              delay => Optional[String]
            }]]]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'TaskTriggers[]',
      mof_is_embedded: true,
    },
    dsc_taskuserprincipal: {
      type: "Optional[Struct[{
              id => Optional[String],
              runlevel => Optional[Enum['Highest', 'Limited']],
              processtokensidtype => Optional[Enum['Default', 'None', 'Unrestricted']],
              logontype => Optional[Enum['Group', 'Interactive', 'InteractiveOrPassword', 'None', 'Password', 'S4U', 'ServiceAccount']],
              requiredprivilege => Optional[Array[String]],
              userid => Optional[String]
            }]]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'TaskUserPrincipal',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_networksetting: {
      type: 'Optional[Struct[{
              name => Optional[String],
              id => Optional[String],
            }]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'NetworkSetting',
      mof_is_embedded: true,
    },
    dsc_taskgroupprincipal: {
      type: "Optional[Struct[{
              id => Optional[String],
              runlevel => Optional[Enum['Highest', 'Limited']],
              groupid => Optional[String],
              processtokensidtype => Optional[Enum['Default', 'None', 'Unrestricted']],
              requiredprivilege => Optional[Array[String]]
            }]]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'TaskGroupPrincipal',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: ' ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_taskaction: {
      type: 'Optional[Array[Struct[{
              execute => Optional[String],
              arguments => Optional[String],
              id => Optional[String],
              workingdirectory => Optional[String]
            }]]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'TaskAction[]',
      mof_is_embedded: true,
    },
    dsc_path: {
      type: 'String',
      desc: ' ',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tasksettingsset: {
      type: "Optional[Struct[{
              runonlyifidle => Optional[Boolean],
              idlesetting => Struct[{
                waittimeout => Optional[String],
                restartonidle => Optional[Boolean],
                idleduration => Optional[String],
                stoponidleend => Optional[Boolean],
                cim_instance_type => Enum['IdleSetting']
              }],
              priority => Optional[String],
              restartcount => Optional[String],
              waketorun => Optional[Boolean],
              allowhardterminate => Optional[Boolean],
              hidden => Optional[Boolean],
              volatile => Optional[Boolean],
              deleteexpiredtaskafter => Optional[String],
              disallowstartonremoteappsession => Optional[Boolean],
              restartinterval => Optional[String],
              disallowstartifonbatteries => Optional[Boolean],
              stopifgoingonbatteries => Optional[Boolean],
              multipleinstances => Optional[Enum['IgnoreNew', 'Parallel', 'Queue']],
              useunifiedschedulingengine => Optional[Boolean],
              executiontimelimit => Optional[String],
              allowdemandstart => Optional[Boolean],
              compatibility => Optional[Enum['At', 'V1', 'Vista', 'Win7', 'Win8']],
              startwhenavailable => Optional[Boolean],
              runonlyifnetworkavailable => Optional[Boolean],
              enabled => Optional[Boolean]
            }]]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'TaskSettingsSet',
      mof_is_embedded: true,
    },
  },
)
